import json
import os
import sys

PATH = os.path.join(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)))
sys.path.append(PATH)
print(PATH)

from winhye_common.session.session_redis import RedisConnection




def test_redis():
    redis_conn = RedisConnection(
        '121.40.111.33',
        6379,
        1,
        'winhye@1',
    )
    redis_conn.set('111', '111')
    vv = redis_conn.get('111')
    print(vv)
    redis_conn.delete('111')

if __name__ == '__main__':
    test_redis()



import json
import os
import sys

from winhye_common.utils.sms import Sample

PATH = os.path.join(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)))
sys.path.append(PATH)
print(PATH)


def test_oss_a(phone_numbers, sign_name, template_code, template_param):
    # 再发送
    aa = Sample(
        'LTAI5tG9WoZ4CQpdfEHhfVCb',
        'FuOX7YpIG3sqPVENmb6ryYdhFubVJl'
    )
    res = aa.send_sms(phone_numbers, sign_name, template_code, template_param)
    print()

if __name__ == '__main__':
    # loop = asyncio.get_event_loop()
    test_oss_a(
        '13032643571',
        "北京云汉通航科技有限公司",
        "SMS_223060267",
        {"code": "666666"}
    )
    # asyncio.run(main('17737263251',
    #                  "北京云汉通航科技有限公司",
    #                  "SMS_223060267",
    #                  '{"code":"55"}'))



import redis

__all__ = ['RedisConnection']


class RedisConnection:
    def __init__(self, host, port, db, password):
        self.__poll = redis.ConnectionPool(host=host, port=port, password=password, max_connections=1000, db=db)
        self.__redis = redis.Redis(connection_pool=self.__poll)

    def set(self, key, value, ex=None):
        return self.__redis.set(key, value, ex)

    def get(self, key):
        if self.__redis.exists(key):
            return self.__redis.get(key)
        else:
            return None

    def query_all_redis(self):
        keys = self.__redis.keys()
        result = []
        for k in keys:
            try:
                key = str(k.decode())
                result.append({
                    'key': key,
                    'value': str(self.__redis.get(key).decode('unicode_escape')),
                })
            except:
                pass
        return result

    def delete(self, key):
        if self.__redis.exists(key):
            return self.__redis.delete(key)
        else:
            return None
